@@ -119,10 +119,10 @@ class Creator(RESTInterface):
         self,
         timestamp: float,
         topic_id: UUID,
-        offset: int,
-        length: int,
-        data_offset: int,
-        data_length: int,
+        offset: Optional[int] = None,
+        length: Optional[int] = None,
+        data_offset: Optional[int] = None,
+        data_length: Optional[int] = None,
         errored: Optional[bool] = False,
         archived: Optional[bool] = False,
         error: Optional[dict] = None,
@@ -136,6 +136,7 @@ class Creator(RESTInterface):
         message_data: Optional[dict] = None,
         message_type_id: Optional[UUID] = None,
         ingestion_id: Optional[UUID] = None,
+        payload: Optional[str] = None,
     ):
         args = locals()
         data = self._get_payload_data(args, ["topic_id"])
